#include <algorithm>
#include <queue>
#include <cstdlib>
#include <vector>
#include <cstdio>
#include <vector>
using namespace std;

const int MAXN = 100*100+10;

int n;
vector<int> edge[MAXN];
int m1[MAXN], m2[MAXN], c[MAXN];

int dfs(int u) {
    if (u<0) return 1;
    if (c[u]) return 0;
    c[u] = 1;
    for(vector<int>::iterator i=edge[u].begin();i!=edge[u].end();i++) 
        if (dfs(m2[*i])) {
            m1[u] = *i;
            m2[*i] = u;
            return 1;
        }
    return 0;
}



int mate[MAXN];
int label[MAXN];
int base[MAXN];
int prev1[MAXN];
int prev2[MAXN];
bool mark[MAXN];
int parent[MAXN];
int size[MAXN];

int set_find(int i) {
    if (parent[i] != i) parent[i] = set_find(parent[i]);
    return parent[i];
}

int set_union(int i, int j) {
    if (size[i] < size[j]) {
        parent[i] = j;
        size[j] += size[i];
        return j;
    } else {
        parent[j] = i;
        size[j] += size[i];
        return i;
    }
}

bool prepare(int i, int j) {
    mark[j] = true;
    while(!mark[i]) {
        mark[i] = true;
        if (mate[j] != -1) swap(i, j);
        else if (mate[i] == -1) return true;
        i = base[set_find(prev2[mate[i]])];
    }
    mark[i] = false;
    while (i != j) {
        i = base[set_find(prev2[mate[i]])];
        mark[i] = false;
    }
    return false;
}

void shrink(int i, int b1, int b2, queue<int> &Q) {
    int cur_set = set_find(i);
    while(mark[i]) {
        prev1[i] = b1;
        prev2[i] = b2;
        int next_set = set_find(prev2[mate[i]]);
        cur_set = set_union(cur_set, set_union(set_find(mate[i]), next_set));
        base[cur_set] = base[next_set];
        Q.push(mate[i]);
        i = base[next_set];
    }
}

bool make_blossom(int i, int j, int bi, int bj, queue<int> &Q) {
    if (i==j) return false;
    if (prepare(i,j)) return true;
    shrink(i, bi, bj, Q);
    shrink(j, bj, bi, Q);
    return false;
}

void rematch(int i, int j) {
    int next = mate[i];
    mate[i] = j;
    if (next == -1) return;
    mate[next] = -1;
    rematch(prev2[next], prev1[next]);
    rematch(prev1[next], prev2[next]);
}

bool augment() {
    queue<int> Q;
    for(int i=0; i<n; i++) {
        label[i] = mate[i] == -1;
        if (mate[i] == -1) Q.push(i);
        mark[i] = false;
        base[i] = parent[i] = i;
        size[i] = 1;
    }
    while(!Q.empty()) {
        int cur = Q.front();
        Q.pop();
        for(vector<int>::iterator i=edge[cur].begin();i!=edge[cur].end();i++) 
            if ((*i) != mate[cur]) {
                if (label[*i] == 0) {
                    label[*i] = -1;
                    label[mate[*i]] = 1;
                    Q.push(mate[*i]);
                    prev1[*i] = *i;
                    prev2[*i] = cur;
                }
                else {
                    int b = base[set_find(*i)];
                    if (label[b] == 1 && make_blossom(b, base[set_find(cur)], *i, cur, Q)) {
                        rematch(*i, cur);
                        rematch(cur, *i);
                        return true;
                    }
                }
            }
    }
    return false;
}

int compute_gcm() {
    fill_n(mate, n, -1);
    int result = 0;
    while(augment()) ++result;
    return result;
}

bool check(int u) {
    return (1==label[set_find(u)]);
}

void scase() {
    char board[101][101];
    int rows, cols;
    scanf("%d%d",&rows,&cols);
    if (rows==0 && cols==0)
        exit(0);
    for(int i=0;i<rows;i++)
        scanf("%s",board[i]);
    n = rows*cols;
    for(int i=0;i<rows;i++)
        for(int j=0;j<cols;j++)
            if (board[i][j]=='.') {
                if (i>0 && board[i-1][j]=='.') edge[i*cols+j].push_back((i-1)*cols+j);
                if (j>0 && board[i][j-1]=='.') edge[i*cols+j].push_back(i*cols+(j-1));
                if (i<rows-1 && board[i+1][j]=='.') edge[i*cols+j].push_back((i+1)*cols+j);
                if (j<cols-1 && board[i][j+j]=='.') edge[i*cols+j].push_back(i*cols+(j+1));
            }
    compute_gcm();
    for(int i=0;i<n;i++) edge[i].clear();
    for(int i=0;i<rows;i++)
        for(int j=0;j<cols;j++)
            if (board[i][j]=='.') {
                if (check(i*rows+j))
                    board[i][j] = 'A';
                else
                    board[i][j] = 'B';
            }
    for(int i=0;i<rows;i++)
        printf("%s\n",board[i]);
    printf("\n");
}

int main() {
    for(;;) scase();
}

