#include <complex>
#include <vector>
#include <cstdio>
#include <cstdlib>
#include <algorithm>
using namespace std;

typedef long double LD;
typedef complex<LD> Point;
typedef pair<Point,Point> Segment;
#define X real()
#define Y imag()

const LD EPS = 1e-9;

const LD TPI = 4.0*acosl(0);

int cmp1(Point a, Point b) {
    
    LD an = norm(a);
    LD bn = norm(b);

    if (fabsl(an-bn) > EPS) {
        if (an<bn) return -1; else return 1;
    }

    if ((an+bn) < EPS) return 0;

    LD aa = arg(a);
    LD bb = arg(b);
    if (fabsl(aa-bb) < EPS || fabs(aa-bb+TPI) < EPS || fabs(aa-bb-TPI) < EPS) return 0;
    if (aa<bb) return -1; else return 1;
}

bool cmp2(Segment a, Segment b) {

    int c1 = cmp1(a.first, b.first);
    if (c1!=0) return c1<0;
    return cmp1(a.second, b.second) < 0;
}

bool inside(Segment a, Point p) {

    if ( p.X < min(a.first.X, a.second.X) - EPS ) return false;
    if ( p.Y < min(a.first.Y, a.second.Y) - EPS ) return false;
    if ( p.X > max(a.first.X, a.second.X) + EPS ) return false;
    if ( p.Y > max(a.first.Y, a.second.Y) + EPS ) return false;

    return true;
}

LD myarg(Point a) { 
    if (norm(a) < EPS) return 0; else return arg(a);
}

LD ccw(Point a, Point b) { return a.X * b.Y - a.Y * b.X; }

bool overlap(Segment a, Segment b) {

    if ( fabsl(ccw(a.first-a.second, b.first-a.second)) > EPS  ) return false;
    if ( fabsl(ccw(a.first-a.second, b.second-a.second)) > EPS  ) return false;

    if (inside(a, b.first)) return true;
    if (inside(a, b.second)) return true;
    if (inside(b, a.first)) return true;
    if (inside(b, a.second)) return true;

    return false;
}

Point mini(Point a, Point b) { 
    if ((a.X < b.X) || ((a.X == b.X) && (a.Y < b.Y))) return a; else return b;
}
Point maxi(Point a, Point b) { 
    if ((a.X > b.X) || ((a.X == b.X) && (a.Y > b.Y))) return a; else return b;
}


vector<LD> getData() {
    
    vector<Segment> v1;

    Point cur = 0;

    while(true) {
        
        char buf[4];
        Point d;
        scanf("%s",buf);
        if (buf[0]=='E') break;
        if (buf[0]=='Q') exit(0);
        scanf("%Lf%Lf",&d.X,&d.Y);

        if (buf[0]=='L') {
            v1.push_back(Segment(cur,cur+d));
        }
        cur += d;

    }

    if (v1.empty()) {
        vector<LD> r;
        return r;
    }

    for(int i=0;i<v1.size();i++) {
        for(int j=0;j<i;j++) {
            if (!overlap(v1[i],v1[j])) continue;
            Segment seg;
            seg.first = mini(mini(v1[i].first,v1[i].second),mini(v1[j].first,v1[j].second));
            seg.second = maxi(maxi(v1[i].first,v1[i].second),maxi(v1[j].first,v1[j].second));

            v1.erase(v1.begin() + j);
            v1[i-1] = seg;
            i-=2;
            break;
        }
    }
            

    Point cent = 0;
    for(int i=0;i<v1.size();i++) 
        cent += (v1[i].first+v1[i].second);

    cent /= LD(v1.size()*2);

    for(int i=0;i<v1.size();i++) {
        v1[i].first -= cent;
        v1[i].second -= cent;
    }

    LD best = 0;
    for(int i=0;i<v1.size();i++) 
        best = max(best, max(norm(v1[i].first), norm(v1[i].second)));
    
    best = sqrtl(best);
    
    if (best > 0) {
        for(int i=0;i<v1.size();i++) {
            v1[i].first /= best;
            v1[i].second /= best;
        }
    }
    
    int n = v1.size();
    for(int i=0;i<n;i++) v1.push_back(Segment(v1[i].second, v1[i].first));

    sort(v1.begin(), v1.end(), cmp2);

    vector<Point> v2;
    for(int i=0;i<v1.size();i++) {
        v2.push_back(v1[i].first);
        v2.push_back(v1[i].second);
    }

    v2.push_back(v2[0]);

    vector<LD> v3;

    for(int i=0;i<v2.size()-1;i++) {
        v3.push_back(norm(v2[i]));
        LD ang = myarg(v2[i]) - myarg(v2[i+1]);
        ang = fmodl(fmodl(ang,TPI)+TPI,TPI);
        if (fabsl(ang-TPI) < EPS) ang = 0;
        v3.push_back(ang);
    }
    
//    for(int i=0;i<v3.size();i++) printf("%llf ",v3[i]); printf("\n");

        
    return v3;
}

bool scase() {

    vector<LD> u,v;
    u = getData();
    v = getData();
    
    if (u.size() != v.size()) return 0;
    
    int n = u.size();

    LD w[3*n+10];
    int p[3*n+10];

    for(int i=0;i<n;i++) w[i] = u[i];
    w[n] = 1e9;
    for(int i=0;i<n;i++) w[n+1+i] = w[2*n+1+i] = v[i];

    int g = 0;
    p[0] = 0;
    for(int i=1;i<3*n+1;i++) {
        p[i] = max(min(p[i-g], p[g]+g-i), 0);
        while (i+p[i] < 3*n+1 && (fabsl(w[p[i]]-w[i+p[i]])<EPS)) p[i]++;
        if (p[i]+i > p[g] + g) g=i;
    }

    for(int i=0;i<n;i+=4)
        if (p[n+1+i] >= n) return true;

    return false;

}

int main() {
    for(;;) if (scase()) { printf("YES\n"); } else { printf("NO\n"); }
}


