/*
 * CTU Open Contest 2011
 *
 * Sample solution: Polygon
 * Author: Martin Kacer
 */

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.StringTokenizer;
import java.util.TreeSet;

public class polygon {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	public static void main(String[] args) throws Exception {
		polygon instance = new polygon();
		while (instance.run()) {/*repeat*/}
	}
	String nextToken() throws Exception {
		while (!st.hasMoreTokens()) st = new StringTokenizer(input.readLine());
		return st.nextToken();
	}
	int nextInt() throws Exception {
		return Integer.parseInt(nextToken());
	}

	static class Point implements Comparable<Point> {
		final int x, y;
		Point(int x, int y) { this.x = x; this.y = y; }
		public int compareTo(Point other) {
			if (this.x < other.x) return -1;
			if (this.x > other.x) return +1;
			return this.y - other.y;
		}
		public String toString() { return "["+x+","+y+"]"; }
	}
	static class Endpoint implements Comparable<Endpoint> {
		final Point pt; final Segment seg;
		Endpoint(Point pt, Segment seg) {
			this.pt = pt; this.seg = seg;
		}
		public int compareTo(Endpoint other) {
			if (this.pt.x < other.pt.x) return -1;
			if (this.pt.x > other.pt.x) return +1;
			// right points go first (first add to an active set, then remove)
			if (this.seg.left == this.pt && other.seg.right == other.pt) return -1;
			if (this.seg.right == this.pt && other.seg.left == other.pt) return +1;
			return this.pt.y - other.pt.y;
		}
		public String toString() { return (seg.left == pt ? "start" : "end") + "["+pt.x+","+pt.y+"]"; }
	}

	static class Segment implements Comparable<Segment> {
		final Point left, right;
		Segment prev;
		Segment(int x1, int y1, int x2, int y2) {
			if (x1 > x2) {
				this.left = new Point(x2,y2);
				this.right = new Point(x1,y1);
			} else {
				this.left = new Point(x1,y1);
				this.right = new Point(x2,y2);
			}
		}
		public String toString() { return left.toString() + "-" + right; }

		public int compareTo(Segment other) {
			int cmp = this.left.compareTo(other.left);
			if (cmp != 0) return cmp;
			cmp = this.right.compareTo(other.right);
			return (cmp != 0) ? cmp
					: Integer.valueOf(this.hashCode()).compareTo(Integer.valueOf(other.hashCode()));
			// we need a tie-breaker because the TreeSet cannot have "equal" keys
		}
	}
	static class LeftYComparator implements Comparator<Segment> {
		public int compare(Segment s1, Segment s2) {
			int cmp = s1.left.y - s2.left.y;
			return (cmp != 0) ? cmp : s1.compareTo(s2);
		}
	}

	/**
	 * Test whether two line segments intersect or not.
	 */
	boolean intersects(int x1, int y1, int x2, int y2,
			int x3, int y3, int x4, int y4) {
		int d0 = (y4-y3)*(x2-x1) - (x4-x3)*(y2-y1);
		int d1 = (x4-x3)*(y1-y3) - (y4-y3)*(x1-x3);
		int d2 = (x2-x1)*(y1-y3) - (y2-y1)*(x1-x3);
		if (d0 != 0) {
			if (d0 < 0) { d0=-d0; d1=-d1; d2=-d2;}
			return d1 >= 0 && d1 <= d0
				&& d2 >= 0 && d2 <= d0;
		}
		if (d1 != 0) return false;
		if (x1 == x2) { x1 = y1; x2 = y2; x3 = y3; x4 = y4; }
		if (x1 > x2) { y1 = x1; x1 = x2; x2 = y1; }
		if (x3 > x4) { y1 = x3; x3 = x4; x4 = y1; }
		return x2 >= x3 && x4 >= x1;
	}
	
	boolean soFarSoGood;
	TreeSet<Segment> active = new TreeSet<Segment>(new LeftYComparator());
	List<Endpoint> endpoints = new ArrayList<Endpoint>();
	
	/** Mark two segments as neighboring.
	 * Also check whether they overlap! (this is the main purpose of this method)
	 * (xc,yc) give the common point
	 */
	void makeNeighbors(Segment a, Segment b, int xc, int yc) {
		a.prev = b;
		if ((a.right.x-a.left.x) * (b.right.y-b.left.y) != (a.right.y-a.left.y)*(b.right.x-b.left.x)) return;
		// colinear!
		Point pa = (a.left.x == xc && a.left.y == yc) ? a.right : a.left;
		Point pb = (b.left.x == xc && b.left.y == yc) ? b.right : b.left;
		int ad, bd;
		if (a.left.x != a.right.x) {
			ad = pa.x - xc; bd = pb.x - xc;
		} else {
			ad = pa.y - yc; bd = pb.y - yc;
		}
		if ((ad < 0 && bd < 0) || (ad > 0 && bd > 0))
			soFarSoGood = false;
		/*
		Example of the input failing without the test above
		7
		4 0
		1 3
		-3 1
		-3 -1
		1 -3
		3 0
		0 0
		This would say: YES, simple polygon (but that is not true)
		*/
	}
	
	boolean run() throws Exception {
		int cntpoints = nextInt();
		if (cntpoints == 0) return false;
		active.clear(); endpoints.clear();
		soFarSoGood = true;
		int x0 = nextInt(), y0 = nextInt(), xp = x0, yp = y0;
		Segment prev = null, first = null;
		for (int i = 1; i < cntpoints; ++i) {
			int x = nextInt(), y = nextInt();
			Segment s = new Segment(xp, yp, x, y);
			if (prev != null) makeNeighbors(s, prev, xp, yp);
			prev = s; xp = x; yp = y;
			if (i == 1) first = s;
			endpoints.add(new Endpoint(s.left, s));
			endpoints.add(new Endpoint(s.right, s));
		}
		Segment s = new Segment(xp, yp, x0, y0);
		makeNeighbors(s, prev, xp, yp); makeNeighbors(first, s, x0, y0);
		endpoints.add(new Endpoint(s.left, s));
		endpoints.add(new Endpoint(s.right, s));
		Collections.sort(endpoints);
		
		for (Endpoint ep : endpoints) {
			if (!soFarSoGood) break;
			if (ep.pt == ep.seg.left) {
				active.add(ep.seg);
				checkSegments(ep.seg, active.lower(ep.seg));
				checkSegments(ep.seg, active.higher(ep.seg));
			} else {
				checkSegments(active.lower(ep.seg), active.higher(ep.seg));
				active.remove(ep.seg);
			}
			//System.out.println(" DBG: active: " + ep + " -> " + active);
		}
		System.out.println(soFarSoGood ? "YES" : "NO");
		return true;
	}
	
	void checkSegments(Segment a, Segment b) {
		if (a == null || b == null) return;
		if (a.prev == b || b.prev == a) return; // TODO: co kdyz se protinaji mimo spolecny endpoint!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
		if (intersects(a.left.x, a.left.y, a.right.x, a.right.y,
				b.left.x, b.left.y, b.right.x, b.right.y))
			soFarSoGood = false;
		//System.out.println(" DBG: " + a + " x " + b + " -> " + !soFarSoGood);
	}
}
