/*
 * CTU Open Contest 2011
 *
 * Sample solution: Domino Tiling
 * Author: Martin Kacer
 */

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public class tiling
{
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	public static void main(String[] args) throws Exception {
		tiling instance = new tiling();
		while (instance.run()) {/*repeat*/}
	}
	String nextToken() throws Exception {
		while (!st.hasMoreTokens()) st = new StringTokenizer(input.readLine());
		return st.nextToken();
	}
	int nextInt() throws Exception {
		String t = nextToken();
		return "X".equals(t) ? -1 : Integer.parseInt(t);
	}


	static class Piece {
		final int a, b, idx;
		public Piece(int a, int b, int i) {
			this.a = (a < b) ? a : b;
			this.b = (a < b) ? b : a;
			this.idx = i;
		}
		@Override public String toString() { return "[" + a + "-" + b + "]"; }
	}
	class Placement {
		final int x, y, idx; final boolean vert;
		public Placement(int x, int y, boolean v, int i) {
			this.x = x; this.y = y; this.vert = v;
			this.idx = i;
		}
		Piece getPiece() { return findpiece[map[x][y]][map[vert?x+1:x][vert?y:y+1]]; }
		@Override public String toString() { return "(" + x + "," + y + (vert ? 'V' : 'H') + ")"; }
	}

	/** numbers in the rectangle and its size */
	int[][] map;
	int rows, cols;
	
	/** available dominoes */
	Piece[] pieces;
	/** easily locate the domino instance by the pair of numbers */
	Piece[][] findpiece;
	
	/** all possible placements */
	Placement[] places;
	/** quickly locate the place by its coordinates */
	Placement[][] vertplac, horizplac;
	/** whether the placements are still possible and selected */
	boolean[] posplaces, selectedplace;
	
	/** all possible places for a piece; and the one selected */
	List<Placement>[] pos4piec;
	Placement[] sel4piec;
	
	/** the result: 'V' - vertical, 'H' - horizontal piece begins here */
	char[][] layout;
	
	int solutionCount;

	/* pieces, rows, and cols must be filled before this method is called!! */
	void init() {
		places = new Placement[rows*(cols-1) + (rows-1)*cols];
		posplaces = new boolean[places.length];
		selectedplace = new boolean[places.length];
		vertplac = new Placement[rows-1][cols]; horizplac = new Placement[rows][cols-1];
		int placcnt = 0;
		for (int i = 0; i < rows; ++i)
			for (int j = 0; j < cols-1; ++j)
				{ places[placcnt] = horizplac[i][j] = new Placement(i, j, false, placcnt); ++placcnt; }
		for (int i = 0; i < rows-1; ++i)
			for (int j = 0; j < cols; ++j)
				{ places[placcnt] = vertplac[i][j] = new Placement(i, j, true, placcnt); ++placcnt; }
		findpiece = new Piece[10][10];
		pos4piec = createArray(pieces.length);
		for (Piece pc : pieces) {
			findpiece[pc.a][pc.b] = findpiece[pc.b][pc.a] = pc;
			pos4piec[pc.idx] = new ArrayList<Placement>();
		}
		sel4piec = new Placement[pieces.length];
	}

	@SuppressWarnings("unchecked")
	private <T> ArrayList<T>[] createArray(int len) {
		return new ArrayList[len];
	}
	
	/** Initial method, find and register all possible placements. */
	void findpossible() {
		for (int i = 0; i < rows; ++i)
			for (int j = 0; j < cols-1; ++j) {
				if (map[i][j] < 0 || map[i][j+1] < 0) continue;
				Piece pc = findpiece[map[i][j]][map[i][j+1]];
				if (pc != null)
					addpos(horizplac[i][j]);
			}
		for (int i = 0; i < rows-1; ++i)
			for (int j = 0; j < cols; ++j) {
				if (map[i][j] < 0 || map[i+1][j] < 0) continue;
				Piece pc = findpiece[map[i][j]][map[i+1][j]];
				if (pc != null)
					addpos(vertplac[i][j]);
			}
	}
	
	/** Mark placement as possible. Called during initialization and tracking BACK. */
	boolean addpos(Placement p) {
		if (posplaces[p.idx]) return false;
		if (p.getPiece() == null) return false;
		posplaces[p.idx] = true;
		pos4piec[p.getPiece().idx].add(p);
		return true;
	}
	
	/** Mark placement as impossible. Called when going DEEP. */
	boolean rempos(Placement p) {
		if (!posplaces[p.idx]) return false;
		posplaces[p.idx] = false;
		pos4piec[p.getPiece().idx].remove(p);
		return true;
	}
	
	/** The main method: recursive backtracing.
	 * A piece that has the less possible placements always goes first. */
	void solve(int level) {
		//uncomment if you only want ANY solution
		//if (solutionCount > 0) return;
		int min = rows*cols*2;
		Piece minpiec = null;
		for (Piece p : pieces) {
			if (sel4piec[p.idx] != null) continue;
			if (pos4piec[p.idx].isEmpty()) return;
			if (pos4piec[p.idx].size() < min) { min = pos4piec[p.idx].size(); minpiec = p; }
		}
		// TODO: additional optimization is to find _squares_ with minimal variant placements
		// and combine these two; this is not implemented in this solution
		List<Placement> undoinfo = new ArrayList<Placement>();
		if (minpiec != null) {
			// TODO: array copy... not very efficient... :-( without it, there is a ConcurrentModificationException
			for (Placement p : pos4piec[minpiec.idx].toArray(new Placement[pos4piec[minpiec.idx].size()])) {
				if (posplaces[p.idx]) {
					assign(level, p, minpiec, undoinfo);
					solve(level+1);
					undo(level, p, minpiec, undoinfo);
				}
			}
		} else {
			if (solutionCount++ == 0)
				display(layout);
		}
	}

	/** Place a piece on some placement. Called when going DEEP. */
	void assign(int level, Placement p, Piece d, List<Placement> undoinfo) {
		//System.err.println("DBG: level=" + level + " assign " + d + " -> " + p);
		layout[p.x][p.y] = p.vert ? 'V' : 'H';
		sel4piec[d.idx] = p;
		selectedplace[p.idx] = true;
		rempos(p);
		// TODO: array copy... not very efficient... :-( without it, there is a ConcurrentModificationException
		for (Placement o : pos4piec[d.idx].toArray(new Placement[pos4piec[d.idx].size()])) {
			if (rempos(o)) undoinfo.add(o);
		}
		removeSquare(p.x, p.y, undoinfo);
		if (p.vert) removeSquare(p.x+1, p.y, undoinfo); else removeSquare(p.x, p.y+1, undoinfo);
	}

	/** Undo all recorded placements. Called when tracking BACK. */
	void undo(int level, Placement p, Piece d, List<Placement> undoinfo) {
		//System.err.println("DBG: level=" + level + " undo " + d + " -> " + p);
		layout[p.x][p.y] = 0;
		sel4piec[d.idx] = null;
		selectedplace[p.idx] = false;
		addpos(p);
		for (Placement u : undoinfo) {
			addpos(u);
		}
	}

	/** Mark some single square unusable (technically, "already used"). */
	void removeSquare(int x, int y, List<Placement> undoinfo) {
		if (x >= 0 && x < rows-1 && y >= 0 && y < cols) removePlac(vertplac[x][y], undoinfo);
		if (x >= 1 && x < rows && y >= 0 && y < cols) removePlac(vertplac[x-1][y], undoinfo);
		if (x >= 0 && x < rows && y >= 0 && y < cols-1) removePlac(horizplac[x][y], undoinfo);
		if (x >= 0 && x < rows && y >= 1 && y < cols) removePlac(horizplac[x][y-1], undoinfo);
	}
	void removePlac(Placement p, List<Placement> undoinfo) {
		if (rempos(p)) undoinfo.add(p);
	}

	/** Show a solution. There was a nicer version but that would be difficult to judge. */
	public static void display(char[][] layout) {
		int rows = layout.length, cols = layout[0].length;
		for (int i = 0; i < rows; ++i) {
			for (int j = 0; j < cols; ++j) {
				if (layout[i][j] == 'X') System.out.append('X');
				else if (layout[i][j] == 'H') System.out.append('[');
				else if (layout[i][j] == 'V') System.out.append('n');
				else if (i > 0 && layout[i-1][j] == 'V') System.out.append('u');
				else System.out.append(']');
			}
			System.out.println();
		}
	}
	
	boolean run() throws Exception {
		rows = nextInt(); cols = nextInt();
		int piececnt = nextInt();
		if (rows == 0) return false;
		solutionCount = 0;
		pieces = new Piece[piececnt];
		for (int i = 0; i < pieces.length; ++i)
			pieces[i] = new Piece(nextInt(), nextInt(), i);
		map = new int[rows][cols];
		layout = new char[rows][cols];
		int placed = 0;
		for (int i = 0; i < rows; ++i)
			for (int j = 0; j < cols; ++j)
				if ((map[i][j] = nextInt()) < 0) { layout[i][j] = 'X'; ++ placed; }
		if (placed % 2 == 1 || rows*cols % 2 == 1) throw new IllegalArgumentException("odd number of squares?");
		if (piececnt == (rows*cols-placed)/2) {
			init();
			findpossible();
			solve(0);
		} else System.out.println("HU?");
		if (solutionCount == 0)
			System.out.println("impossible");
		else
			System.out.println(solutionCount-1);
		System.out.println();
		return true;
	}
}
