#include <string>
#include <fstream>
#include <vector>

enum
{
  PIPE_HORIZONTAL = '',
  PIPE_VERTICAL = '',
  PIPE_CORNER_UL = '',
  PIPE_CORNER_UR = '',
  PIPE_CORNER_DL = '',
  PIPE_CORNER_DR = '',
  PIPE_CROSS = '',
  PIPE_CROSS_BROKEN = 'B',
  PIPE_NONE = ' ',
};

const int maxMatSize = 25;
const int iShift[] = {0, 1, 0, -1};
const int jShift[] = {1, 0, -1, 0};

char mat[maxMatSize][maxMatSize];
int traverseVerticalDirection[maxMatSize][maxMatSize];
int traverseHorizontalDirection[maxMatSize][maxMatSize];
int crossDepths[maxMatSize][maxMatSize];

inline int isSymCorner(char c)
{
  return c == PIPE_CORNER_UL || c == PIPE_CORNER_UR || c == PIPE_CORNER_DL || c == PIPE_CORNER_DR;
}

int main (int argc, char** argv)
{
  std::fstream input("input.txt", std::ios_base::in);
  std::fstream output("output.txt", std::ios_base::out);

  int startI = -1, startJ = -1;
  int w, h;
  input >> h >> w;

  std::string foo;
  std::getline(input, foo); // TODO : find a better way
  int crossesCount = 0;
  for (int i = 0; i < h; i++)
  {
    std::string line;
    std::getline(input, line);

    for (int j = 0; j < w; ++j)
    {
      mat[i][j] = line[j];

      if (mat[i][j] != PIPE_NONE)
      {
        if (startI == -1 && startJ == -1)
        {
          startI = i;
          startJ = j;
        }
      }
      if (mat[i][j] == PIPE_CROSS) crossesCount++;
    }
  }

  int i = startI;
  int j = startJ;
  int dir = 0;
  do
  {
    i += iShift[dir];
    j += jShift[dir];

    if (isSymCorner(mat[i][j])) dir = (dir + 1) % 4;
    else
    if (mat[i][j] == PIPE_VERTICAL || mat[i][j] == PIPE_HORIZONTAL || mat[i][j] == PIPE_CROSS)
    {
      if (dir % 2 == 0) traverseHorizontalDirection[i][j] = 2 * (dir == 0) - 1;
      if (dir % 2 == 1) traverseVerticalDirection[i][j] = 2 * (dir == 1) - 1;
    }
  }
  while (i != startI || j != startJ);

  // TODO : make sure that all tests have only one max-winded area
  int maxWinding = 0;
  int maxWindingI = -1;
  int maxWindingJ = -1;
  for (int i = 0; i < h; ++i)
  {

    int curDepth = 0;
    for (int j = 0; j < w; ++j)
    {
      if (traverseVerticalDirection[i][j] == -1 || mat[i][j] == PIPE_CORNER_DR) curDepth++;
      if (traverseVerticalDirection[i][j] == +1 || mat[i][j] == PIPE_CORNER_DL) curDepth--;
      if (mat[i][j] == PIPE_CROSS) crossDepths[i][j] = curDepth;

      if (curDepth > maxWinding)
      {
        maxWinding = curDepth;
        maxWindingI = i;
        maxWindingJ = j;
      }
    }
  } 
  output << crossesCount - maxWinding + 1;

  i = startI;
  j = startJ;
  dir = 0;
  int crossDependenciesProcessed = 0;
  std::vector<bool> usedRank(maxWinding - 1);
  do
  {
    i += iShift[dir];
    j += jShift[dir];

    if (isSymCorner(mat[i][j])) dir = (dir + 1) % 4;
    else
    if (mat[i][j] == PIPE_CROSS || mat[i][j] == PIPE_CROSS_BROKEN)
    {
      int rank = -1;
      if (traverseVerticalDirection[i][j] == -1 && traverseHorizontalDirection[i][j] == -1) rank = maxWinding - 1 - crossDepths[i][j];
      if (traverseVerticalDirection[i][j] == +1 && traverseHorizontalDirection[i][j] == +1) rank = maxWinding - 1 - crossDepths[i][j];
      if (traverseVerticalDirection[i][j] == +1 && traverseHorizontalDirection[i][j] == -1) rank = maxWinding - 2 - crossDepths[i][j];
      if (traverseVerticalDirection[i][j] == -1 && traverseHorizontalDirection[i][j] == +1) rank = maxWinding - crossDepths[i][j];

      if (!usedRank[rank])
        usedRank[rank] = true;
      else
      if (mat[i][j] != PIPE_CROSS_BROKEN)
        output << std::endl << i << " " << j;

      mat[i][j] = PIPE_CROSS_BROKEN;
      crossDependenciesProcessed++;
    }
  }
  while (crossDependenciesProcessed < 2 * crossesCount);
  
  return 0;
}
