/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem C. Cube Coloring                                     */
/*                                                              */
/* Original idea         Georgiy Korneev                        */
/* Problem statement     Maxim Buzdalov                         */
/* Testset               Maxim Buzdalov                         */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Anton Akhi                             */
/*--------------------------------------------------------------*/
 
import java.io.*;
import java.util.*;

public class cube_aa_wa {

    public static void main(String[] args) {
        new cube_aa_wa().run();
    }

    BufferedReader br;
    StringTokenizer st;
    PrintWriter out;
    boolean eof = false;
    Random rand = new Random(34611256);

    void run() {
        try {
            br = new BufferedReader(new FileReader(FNAME + ".in"));
            out = new PrintWriter(FNAME + ".out");
            solve();
            out.close();
        } catch (Throwable e) {
            e.printStackTrace();
            System.exit(566);
        }
    }

    String nextToken() {
        while (st == null || !st.hasMoreTokens()) {
            try {
                st = new StringTokenizer(br.readLine());
            } catch (Exception e) {
                eof = true;
                return "0";
            }
        }
        return st.nextToken();
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    void myAssert(boolean u, String message) {
        if (!u) {
            throw new Error("Assertion error!!! " + message);
        }
    }

    int nextBoundedInt(int l, int r, String name) {
        int x = nextInt();
        myAssert(l <= x && x <= r, name + " = " + x + " not in [" + l + ".."
                + r + "]");
        return x;
    }

    String FNAME = "cube";

    int FACES = 6;

    int[][] perms = new int[][] { { 1, 2, 3, 4 }, { 1, 2, 4, 3 },
            { 1, 3, 2, 4 }, { 1, 3, 4, 2 }, { 1, 4, 2, 3 }, { 1, 4, 3, 2 },
            { 2, 1, 3, 4 }, { 2, 1, 4, 3 }, { 2, 3, 1, 4 }, { 2, 3, 4, 1 },
            { 2, 4, 1, 3 }, { 2, 4, 3, 1 }, { 3, 1, 2, 4 }, { 3, 1, 4, 2 },
            { 3, 2, 1, 4 }, { 3, 2, 4, 1 }, { 3, 4, 1, 2 }, { 3, 4, 2, 1 },
            { 4, 1, 2, 3 }, { 4, 1, 3, 2 }, { 4, 2, 1, 3 }, { 4, 2, 3, 1 },
            { 4, 3, 1, 2 }, { 4, 3, 2, 1 } };

    private void solve() throws IOException {
        char[][] colors = new char[FACES][];
        for (int i = 0; i < colors.length; i++) {
            colors[i] = nextToken().toCharArray();
            myAssert(colors[i].length == FACES - 1, "Wrong line length: "
                    + Arrays.toString(colors[i]));
            for (int j = 0; j < colors[i].length; j++) {
                myAssert('A' <= colors[i][j] && colors[i][j] <= 'Z',
                        "Unexpected symbol: " + colors[i][j]);
            }
        }
        nextToken();
        myAssert(eof, "Extra information in input!!!");

        normaliaze(colors);
        char[] cube = new char[FACES];
        cube[0] = colors[0][0];
        for (int p = 0; p < perms.length && ts.size() < 2; p++) {
            for (int i = 1; i < cube.length - 1; i++) {
                cube[i] = colors[0][perms[p][i - 1]];
            }
            for (int i = 1; i < colors.length; i++) {
                cube[FACES - 1] = colors[i][0];
                check(cube, colors);
            }
        }
        if (ts.isEmpty()) {
            out.println("Impossible");
        } else {
            for (String s : ts) {
                out.println(s);
            }
        }
    }

    private void check(char[] cube, char[][] colors) {
        char[][] col = new char[FACES][FACES - 1];
        for (int i = 0; i < col.length; i++) {
            col[i][0] = cube[i];
            for (int j = 1; j < col[i].length; j++) {
                col[i][j] = cube[rotations[i][j - 1]];
            }
        }
        normaliaze(col);
        if (Arrays.deepEquals(col, colors)) {
            ts.add(cubeToString(cube));
        }
    }

    private void normaliaze(char[][] col) {
        for (int i = 0; i < col.length; i++) {
            Arrays.sort(col[i], 1, 5);
        }
        Arrays.sort(col, new Comparator<char[]>() {

            @Override
            public int compare(char[] o1, char[] o2) {
                for (int i = 0; i < o1.length; i++) {
                    if (o1[i] != o2[i]) {
                        return o1[i] - o2[i];
                    }
                }
                return 0;
            }
        });
    }

    int[][] rotations = new int[][] { { 1, 2, 3, 4, 5 }, { 0, 4, 5, 2, 3 },
            { 0, 1, 5, 3, 4 }, { 0, 2, 5, 4, 1 }, { 0, 3, 5, 1, 2 },
            { 1, 4, 3, 2, 0 } };

    TreeSet<String> ts = new TreeSet<String>();

    String cubeToString(char[] c) {
        String ans = null;
        for (int i = 0; i < c.length; i++) {
            for (int k = 0; k < 4; k++) {
                String s = "" + c[i];
                for (int j = 0; j < 4; j++) {
                    s += c[rotations[i][(j + k) % 4]];
                }
                s += c[rotations[i][4]];
                if (ans == null || ans.compareTo(s) > 0) {
                    ans = s;
                }
            }
        }
        return ans;
    }
}
