/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem E. Electrification                                   */
/*                                                              */
/* Original idea         Mikhail Dvorkin                        */
/* Problem statement     Mikhail Dvorkin                        */
/* Testset               Mikhail Dvorkin                        */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Anton Akhi                             */
/*--------------------------------------------------------------*/
 
import java.io.*;
import java.util.*;

public class electro_aa {

    public static void main(String[] args) {
        new electro_aa().run();
    }

    BufferedReader br;
    StringTokenizer st;
    PrintWriter out;
    boolean eof = false;
    Random rand = new Random(34611256);

    void run() {
        try {
            br = new BufferedReader(new FileReader(FNAME + ".in"));
            out = new PrintWriter(FNAME + ".out");
            solve();
            out.close();
        } catch (Throwable e) {
            e.printStackTrace();
            System.exit(566);
        }
    }

    String nextToken() {
        while (st == null || !st.hasMoreTokens()) {
            try {
                st = new StringTokenizer(br.readLine());
            } catch (Exception e) {
                eof = true;
                return "0";
            }
        }
        return st.nextToken();
    }

    int nextInt() {
        return Integer.parseInt(nextToken());
    }

    void myAssert(boolean u, String message) {
        if (!u) {
            throw new Error("Assertion error!!! " + message);
        }
    }

    int nextBoundedInt(int l, int r, String name) {
        int x = nextInt();
        myAssert(l <= x && x <= r, name + " = " + x + " not in [" + l + ".."
                + r + "]");
        return x;
    }

    String FNAME = "electro";

    final int MAX_SIZE = 5000;

    class End {
        public End(int i, int j, int k) {
            x = i;
            y = j;
            dest = k;
            d[x][y] = dest;
        }

        @Override
        public boolean equals(Object o) {
            if (!(o instanceof End)) {
                return false;
            }
            End e = (End) o;
            return x == e.x && y == e.y && dest == e.dest;
        }

        @Override
        public String toString() {
            return x + " " + y + " --> " + dest;
        }

        int x, y;
        int dest;

        public int oddity() {
            return (x + y + dest) % 2;
        }

        public void down() {
            if (c[x][y] == '.') {
                c[x][y] = '\\';
            } else {
                c[x][y] = 'X';
            }
            x++;
            y++;
            d[x][y] = dest;
        }

        public void up() {
            if (c[x - 1][y] == '.') {
                c[x - 1][y] = '/';
            } else {
                c[x - 1][y] = 'X';
            }
            x--;
            y++;
            d[x][y] = dest;
        }

        public End fork() {
            End e = new End(x - 1, y, dest);
            c[x - 1][y] = 'L';
            y++;
            d[x][y] = dest;
            return e;
        }

        public void setDest(int k) {
            dest = k;
        }

        public boolean upFree() {
            return x > 0 && d[x - 1][y + 1] < -1;
        }

        public void join() {
            c[x][y] = '7';
            y++;
            d[x][y] = dest;
        }

        public void cross(End e) {
            c[x][y] = 'X';
            down();
            e.up();
        }

        public void rev() {
            c[x - 2][y] = '/';
            c[x - 1][y] = 'L';
            c[x - 2][y + 1] = 'X';
            c[x - 1][y + 1] = 'L';
            c[x - 2][y + 2] = '7';
            c[x - 1][y + 2] = '/';
            c[x - 2][y + 3] = 'X';
            // c[x - 1][y + 3] = '.';
            c[x - 2][y + 4] = '7';
            // c[x - 1][y + 4] = '.';
            d[x - 1][y + 0] = dest;
            d[x - 2][y + 1] = dest;
            d[x - 1][y + 1] = dest;
            d[x - 0][y + 1] = dest;
            d[x - 2][y + 2] = dest;
            d[x - 1][y + 2] = dest;
            d[x - 0][y + 2] = dest;
            d[x - 2][y + 3] = dest;
            d[x - 1][y + 3] = dest;
            d[x - 2][y + 4] = dest;
            d[x - 1][y + 4] = dest;

            x -= 2;
            y += 5;
            d[x][y] = dest;
        }

        void step() {
            up();
            down();
        }

        public void launchUp() {
            // rev();
            up();
            up();
        }

        public void reverse() {
            rev();
            down();
            down();
        }
    }

    final int MAXN = 10;
    final int MAXM = 10;

    private void solve() throws IOException {
        int n = nextBoundedInt(1, MAXN, "n");
        int m = nextBoundedInt(1, MAXM, "m");
        boolean[][] a = new boolean[n][m];
        {
            char[][] asdf = new char[n][];
            for (int i = 0; i < asdf.length; i++) {
                asdf[i] = nextToken().toCharArray();
                myAssert(asdf[i].length == m,
                        "wrong length: " + Arrays.toString(asdf[i]));
                for (int j = 0; j < asdf[i].length; j++) {
                    myAssert(asdf[i][j] == '0' || asdf[i][j] == '1',
                            "Unexpected symbol: " + asdf[i][j]);
                }
            }
            for (int i = 0; i < asdf.length; i++) {
                for (int j = 0; j < a[i].length; j++) {
                    a[i][j] = asdf[i][j] == '1';
                }
            }
        }
        ends = new End[m];
        int[] count = new int[n];
        for (int i = 0; i < count.length; i++) {
            for (int j = 0; j < a[i].length; j++) {
                if (a[i][j]) {
                    count[i]++;
                }
            }
            myAssert(count[i] > 0, "Switch #" + (i + 1)
                    + " doesn't affect any lamp");
        }
        check: for (int i = 0; i < a[0].length; i++) {
            for (int j = 0; j < a.length; j++) {
                if (a[j][i]) {
                    continue check;
                }
            }
            myAssert(false, "Lamp #" + (i + 1)
                    + " isn't affected by any switch");
        }
        int s = 0;
        for (int i = 0; i < count.length; i++) {
            int k = 0;
            End e = new End(i, 0, -1);
            e.down();
            for (int j = 0; j < count[i] - 1; j++) {
                while (e.x < 4 * (s + m + 1)) {
                    e.down();
                }
                while (!a[i][k]) {
                    k++;
                }
                End f = e.fork();
                f.dest = k++;
                up.add(f);
                s++;
            }
            while (e.x < 4 * (s + m + 1) - 1) {
                e.down();
            }
            while (!a[i][k]) {
                k++;
            }
            e.dest = k;
            up.add(e);
            s++;
        }
        norm();
        print();

        int y = 0;
        for (End e : up) {
            y = Math.max(y, e.y);
        }
        for (End e : up) {
            while (e.y < y) {
                e.step();
            }
            e.launchUp();
        }
        print();

        while (!up.isEmpty()) {

            equalize();
            print();

            for (int j = 0; j < up.size(); j++) {
                End e = up.get(j);
                e.up();
                e.up();
                if (e.x == 4 * e.dest + 3) {
                    if (ends[e.dest] == null || ends[e.dest].dest != e.dest) {
                        if (ends[e.dest] != null) {
                            int k = e.dest;
                            End f = ends[k++];
                            while (f != null) {
                                f.down();
                                f.down();
                                f.down();
                                f.down();
                                End t = ends[k];
                                ends[k++] = f;
                                f = t;
                            }
                        }
                        print();
                        e.reverse();
                        ends[e.dest] = e;
                    } else {
                        while (ends[e.dest].y < e.y) {
                            ends[e.dest].step();
                        }
                        print();
                        e.up();
                        print();
                        if (c[e.x][e.y - 1] != 'X') {
                            e.step();
                            ends[e.dest].step();
                        }
                        print();
                        if (ends[e.dest].y < e.y + 1) {
                            ends[e.dest].step();
                        }
                        e.join();
                        s--;
                        print();
                    }
                    up.remove(e);
                } else {
                    e.up();
                    e.up();
                }
            }

        }
        equalize();
        print();
        for (End e : ends) {
            if (e == null) {
                continue;
            }
            if (e.oddity() == 0) {
                e.rev();
                e.up();
            }
        }
        equalize();
        print();

        {
            y = 0;
            for (End e : ends) {
                y = Math.max(y, e.y);
            }
            for (End e : ends) {
                if (e == null) {
                    continue;
                }
                while (e.y < y) {
                    if (e.x == e.dest) {
                        e.down();
                    } else {
                        e.up();
                    }
                }
            }
        }
        while (true) {
            boolean good = true;
            for (End e : ends) {
                if (e == null) {
                    continue;
                }
                good &= e.x == e.dest;
            }
            if (good) {
                break;
            }
            for (End e : ends) {
                if (e == null) {
                    continue;
                }
                if (e.x == e.dest) {
                    e.down();
                } else {
                    e.up();
                }
            }
            print();
        }
        printAns();
    }

    private void norm() {
        print();
        for (End e : up) {
            if ((e.x + e.y) % 2 != 0) {
                e.reverse();
            }
        }
        equalize();
    }

    private void print() {
        if (false) {
            int maxx = 0;
            int maxy = 0;
            for (int i = 0; i < c.length; i++) {
                for (int j = 0; j < c[i].length; j++) {
                    if (c[i][j] != '.') {
                        maxx = Math.max(maxx, i);
                        maxy = Math.max(maxy, j);
                    }
                }
            }
            for (int i = 0; i <= maxx; i++) {
                for (int j = 0; j <= maxy; j++) {
                    System.out.print(c[i][j]);
                }
                System.out.println();
            }
            System.out.println();
        }
        // for (End e : ends) {
        // if (e == null) {
        // continue;
        // }
        // System.out.println(e);
        // }
        // System.out.println("up:");
        // for (End e : up) {
        // System.out.println(e);
        // }
    }

    private void printAns() {
        int maxx = 0;
        int maxy = 0;
        for (int i = 0; i < c.length; i++) {
            for (int j = 0; j < c[i].length; j++) {
                if (c[i][j] != '.') {
                    maxx = Math.max(maxx, i);
                    maxy = Math.max(maxy, j);
                }
            }
        }
        out.println((maxx + 1) + " " + (maxy + 1));
        for (int i = 0; i <= maxx; i++) {
            for (int j = 0; j <= maxy; j++) {
                out.print(c[i][j]);
            }
            out.println();
        }
    }

    private void equalize() {
        int y = 0;
        for (End e : ends) {
            if (e == null) {
                continue;
            }
            y = Math.max(y, e.y);
        }
        for (End e : up) {
            y = Math.max(y, e.y);
        }
        for (int i = 0; i < ends.length; i++) {
            End e = ends[i];
            if (e == null) {
                continue;
            }
            // if (i > 0 && ends[i - 1] == null && d[e.x - 4][e.y + 4] < -1) {
            // e.up();
            // e.up();
            // e.up();
            // e.up();
            // ends[i - 1] = e;
            // ends[i] = null;
            // }
            while (e.y + 2 <= y) {
                e.step();
            }
        }
    }

    char[][] c = new char[MAX_SIZE][MAX_SIZE];
    int[][] d = new int[MAX_SIZE + 1][MAX_SIZE + 1];
    End[] ends;
    ArrayList<End> up = new ArrayList<End>();
    {
        for (int i = 0; i < c.length; i++) {
            Arrays.fill(c[i], '.');
        }
        for (int i = 0; i < d.length; i++) {
            Arrays.fill(d[i], -2);
        }
    }
}