/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem F. Flat                                              */
/*                                                              */
/* Original idea         Fedor Tsarev                           */
/* Problem statement     Fedor Tsarev                           */
/* Testset               Fedor Tsarev                           */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Fedor Tsarev                           */
/*--------------------------------------------------------------*/
 
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.StringTokenizer;
import java.util.Arrays;

public class flat_ft implements Runnable {

	private static final int MIN_N = 1;
	private static final int MAX_N = 10;
	private static final int MIN_C = 1;
	private static final int MAX_C = (int) 1e5;
	private static final int MIN_AREA = 1;
	private static final int MAX_AREA = 100;
	private static final int MIN_TYPE = 1;
	private static final int MAX_TYPE = 5;
	private static final String BEDROOM = "bedroom";
	private static final String BALCONY = "balcony";

	private static final String[] ROOM_TYPES = new String[] {"bedroom", "bathroom", "kitchen", "balcony", "other"};

	private BufferedReader in;
	private StringTokenizer st;
	private PrintWriter out;

	public flat_ft() throws IOException {
		in = new BufferedReader(new FileReader(new File("flat.in")));
		st = new StringTokenizer("");
		out = new PrintWriter(new FileWriter(new File("flat.out")));
	}
	
	public static void main(String[] args) throws IOException {
		new Thread(new flat_ft()).start();
	}
	
	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		} finally { 
			out.close();
		}
	}

	private void solve() throws NumberFormatException, IOException {
		int n = nextInt();
		checkBounds(n, MIN_N, MAX_N, "n");
		int c = nextInt();
		checkBounds(c, MIN_C, MAX_C, "c");
		int[] a = new int[n];
		String[] t = new String[n];
		for (int i = 0; i < n; i++) {
		    a[i] = nextInt();
		    checkBounds(a[i], MIN_AREA, MAX_AREA, "a[" + (i + 1) + "]");
		    t[i] = nextToken();
		    boolean tIsOK = false;
		    for (String type : ROOM_TYPES) {
				if (t[i].equals(type)) {
					tIsOK = true;
					break;
				}		    	
		    }
		    myAssert(tIsOK, "t[" + (i + 1) + "] is incorrect: " + t[i]);
		}
		int totalArea = 0;
		int livingArea = 0;
		int doubledCost = 0;
		for (int i = 0; i < n; i++) {
		    totalArea += a[i];
		    if (t[i].equals(BEDROOM)) {
		        livingArea += a[i];
		    }
		    if (t[i].equals(BALCONY)) {
		        doubledCost += a[i] * c;
		    } else {
    		        doubledCost += 2 * a[i] * c;
		    }
		}
		out.println(totalArea);
		out.println(livingArea);
		out.println(0.5 * doubledCost);
	}

	private String nextToken() throws IOException {
		while (!st.hasMoreTokens()) {
			st = new StringTokenizer(in.readLine());
		}
		return st.nextToken();
	}
	
	private int nextInt() throws NumberFormatException, IOException {
		return Integer.parseInt(nextToken());
	}

	private void myAssert(boolean u, String message) {
		if (!u) {
			throw new Error("Assertion failed!!! " + message);
		}
	}

	private void checkBounds(int x, int min, int max, String name) {
		myAssert((min <= x) && (x <= max), name + " is out of bounds: min = " + min + ", max = " + max + ", " + name + " = " + x);
	}

}
