/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem G. Galaxy                                            */
/*                                                              */
/* Original idea         Andrew Stankevich                      */
/* Problem statement     Oleg Davydov                           */
/* Testset               Oleg Davydov                           */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Anton Bannykh                          */
/*--------------------------------------------------------------*/
 
import java.io.*;
import java.util.*;

public class galaxy_ab {
    public static void main(String[] arg) {
        new galaxy_ab().run();
    }

    StrictScanner in;
    PrintWriter out;
    boolean eof;


    public void run() {
        try {
            in = new StrictScanner(new FileReader("galaxy.in"));
            out = new PrintWriter("galaxy.out");
            solve();
        } catch (Throwable e) {
            e.printStackTrace();
            System.exit(-1);
        } finally {
            out.close();
        }
    }

    final int MAXN = 100000;
    final int MAXM = 100000;

    void solve() throws Exception {
        int n = assertBetween(3, in.loadLine().nextInt(), MAXN, "n");
        k = assertBetween(3, in.skipSpace().nextInt(), n, "k");
        int m = assertBetween(3, in.skipSpace().nextInt(), MAXM, "m");
        G = new ArrayList[n];
        for (int i = 0; i < G.length; ++i) {
            G[i] = new ArrayList<Integer>();
        }
        for (int i = 0; i < m; ++i) {
            int a = assertBetween(1, in.loadLine().nextInt(), n, "a[" + (i + 1) + "]") - 1;
            int b = assertBetween(1, in.skipSpace().nextInt(), n, "b[" + (i + 1) + "]") - 1;
            G[a].add(b);
            G[b].add(a);
        }

        for (int i = k + 1; i < G.length; ++i) {
            assertBetween(0, G[i].size(), k - 1, "deg[" + (i + 1) + "]");
        }

        col = new int[n];
        for (int i = 0; i < k; ++i) {
            col[i] = i + 1;
        }

        cu = new int[k];
        for (int i = 0; i < k; ++i) {
            dfs(i);
        }

        for (int i = 0; i < col.length; ++i) {
            assert col[i] != 0 : "Graph not connected";
            if (i > 0) out.print(" ");
            out.print(col[i]);
        }
        out.println();
    }

    ArrayList<Integer>[] G;
    int[] col;
    int[] cu;
    int ver = 0;
    int k;

    void dfs(int i) {
        if (col[i] == 0) {
            ++ver;
            for (int j : G[i]) {
                if (col[j] != 0) {
                    cu[col[j] - 1] = ver;
                }
            }
        for (int j : G[i]) {
                if (col[j] != 0 && cu[col[j] % k] != ver) {
                    col[i] = col[j] % k + 1;
                    break;
                }
            }
        }
        for (int j : G[i]) {
            if (col[j] != 0) continue;
            dfs(j);
        }
    }


    int assertBetween(int l, int m, int r, String name) {
        assert l <= m && m <= r : "Variable " + name + " = " + m + " not in bounds [" + l + ", " + r + "]";
        return m;
    }

    class StrictScanner extends BufferedReader {

        private String cs;
        private int cpos;

        public StrictScanner(Reader a) {
            super(a);
        }

        boolean eoln() {
            return cpos == cs.length();
        }

        StrictScanner loadLine() throws IOException {
            assert cs == null || eoln();
            cs = readLine();
            cpos = 0;
            return this;
        }

        char nextChar() {
            return cs.charAt(cpos++);
        }

        String nextToken() {
            StringBuilder sb = new StringBuilder();
            while (cpos < cs.length() && cs.charAt(cpos) != ' ') {
                sb.append(cs.charAt(cpos));
                ++cpos;
            }
            return sb.toString();
        }

        int nextInt() {
            return Integer.parseInt(nextToken());
        }

        double nextDouble() {
            return Double.parseDouble(nextToken());
        }

        long nextLong() {
            return Long.parseLong(nextToken());
        }

        StrictScanner skipSpace() {
            char c = nextChar();
            assert c == ' ';
            return this;
        }
    }
}
