/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem I. Immediate Delivery                                */
/*                                                              */
/* Original idea         Pavel Mavrin                           */
/* Problem statement     Pavel Mavrin                           */
/* Testset               Pavel Mavrin                           */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Anton Bannykh                          */
/*--------------------------------------------------------------*/
 
import java.io.*;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;

public class immediate_ab {
    public static void main(String[] arg) {
           new immediate_ab().run();
    }

    StrictScanner in;
    PrintWriter out;
    boolean eof;


    public void run() {
        try {
            String problemName = this.getClass().getName().split("_")[0];
            in = new StrictScanner(new FileReader(problemName + ".in"));
            out = new PrintWriter(problemName + ".out");
            solve();
        } catch (Throwable e) {
            e.printStackTrace();
            System.exit(-1);
        } finally {
            out.close();
        }
    }

    final int MAXN = 20;
    final int MAXW = 1000;
    final int INF = Integer.MAX_VALUE / 4;

    void solve() throws Exception {
        int n = assertBetween(1, in.loadLine().nextInt(), MAXN, "n");
        int m = assertBetween(0, in.skipSpace().nextInt(), n * (n - 1) / 2, "m");
        G = new int[n][n];
        M = new int[n][n];
        Q = new int[n][n];
        for (int i = 0; i < n; ++i) {
            for (int j = 0; j < n; ++j) {
                G[i][j] = INF;
                M[i][j] = ((1 << i) | (1 << j)) >> 1;
                Q[i][j] = i;
            }
        }
        for (int i = 0; i < m; ++i) {
            int a = assertBetween(1, in.loadLine().nextInt(), n, "x_{" + (i + 1) + "}") - 1;
            int b = assertBetween(1, in.skipSpace().nextInt(), n, "y_{" + (i + 1) + "}") - 1;
            int w = assertBetween(1, in.skipSpace().nextInt(), MAXW, "t_{" + (i + 1) + "}");
            assert a != b;
            assert G[a][b] == INF : "Duplicate egde + <" + (a + 1) + ", " + (b + 1);
            G[a][b] = w;
            G[b][a] = w;
        }

        for (int k = 0; k < n; ++k) {
            for (int i = 0; i < n; ++i) {
                for (int j = 0; j < n; ++j) {
                    if (G[i][j] > G[i][k] + G[k][j]) {
                        G[i][j] = G[i][k] + G[k][j];
                        M[i][j] = M[i][k] | M[k][j];
                        Q[i][j] = Q[k][j];
                    }
                }
            }
        }

        D = new int[1 << n - 1][n];
        P = new int[1 << n - 1][n];
        F = new int[1 << n - 1][n];
        for (int[] t1 : D) {
            Arrays.fill(t1, INF);
        }
        D[0][0] = 0;
        for (int mask = 0; mask < D.length - 1; ++mask) {
            for (int i = 0; i < n; ++i) {
                if (D[mask][i] >= INF) continue;
                for (int j = 1; j < n; ++j) {
                    if (((1 << j - 1) & mask) == 0 && D[mask | M[i][j]][j] > D[mask][i] + G[i][j]) {
                        D[mask | M[i][j]][j] = D[mask][i] + G[i][j];
                        P[mask | M[i][j]][j] = i;
                        F[mask | M[i][j]][j] = mask;
                    }
                }
            }
        }
//        System.err.println(Arrays.deepToString(D));

        int[] MM = new int[D.length];
        int[] MD = new int[D.length];
        int[] MJ = new int[D.length];

        for (int mask = D.length - 1; mask >= 0; --mask) {
            MM[mask] = INF;
            for (int i = 0; i < n; ++i) {
                if (MM[mask] > D[mask][i]) {
                    MM[mask] = D[mask][i];
                    MD[mask] = mask;
                    MJ[mask] = i;
                }
            }
            for (int j = 1; j < n; ++j) {
                int tmask = mask | (1 << j - 1);
                if (tmask != mask && MM[mask] > MM[tmask]) {
                    MM[mask] = MM[tmask];
                    MD[mask] = MD[tmask];
                    MJ[mask] = MJ[tmask];
                }
            }
        }
//        System.err.println(Arrays.toString(MM));
//        System.err.println(MM[(1 << 0) | (1 << 1) | (1 << 4) | (1 << 5)]);
//        System.err.println(MM[(1 << 5) - 1]);
        int mmax = 0;
        int mv = INF;
        int MASK = ((1 << n - 1) - 1);
        for (int mask = 0; mask < MM.length; ++mask) {
            int tt = Math.max(MM[mask], MM[MASK ^ mask]);
            if (mv > tt) {
                mv = tt;
                mmax = mask;
            }
        }
        out.println(mv);
        printPath(MD[mmax], MJ[mmax]);
        printPath(MD[MASK ^ mmax], MJ[MASK ^ mmax]);
    }

    int[][] G, M, Q;
    int[][] D, P, F;

    void printPath(int mask, int i) {
        ArrayList<Integer> l = getPath(mask, i);
        out.print(l.size() - 1);
        for (int j = l.size() - 1; j >= 0; --j) {
            out.print(" " + (l.get(j) + 1));
        }
        out.println();
    }

    ArrayList<Integer> getPath(int mask, int i) {
        ArrayList<Integer> ans = new ArrayList<Integer>();
        while (mask != 0) {
            int j = P[mask][i];
            mask = F[mask][i];
            while (i != j) {
                ans.add(i);
                i = Q[j][i];
//                System.err.println(i);
            }
        }
        ans.add(0);
        return ans;
    }

    int assertBetween(int l, int m, int r, String name) {
        assert l <= m && m <= r : "Variable " + name + " = " + m + " not in bounds [" + l + ", " + r + "]";
        return m;
    }

    class StrictScanner extends BufferedReader {

        private String cs;
        private int cpos;

        public StrictScanner(Reader a) {
            super(a);
        }

        boolean eoln() {
            return cpos == cs.length();
        }

        StrictScanner loadLine() throws IOException {
            assert cs == null || eoln();
            cs = readLine();
            cpos = 0;
            return this;
        }

        char nextChar() {
            return cs.charAt(cpos++);
        }

        String nextToken() {
            StringBuilder sb = new StringBuilder();
            while (cpos < cs.length() && cs.charAt(cpos) != ' ') {
                sb.append(cs.charAt(cpos));
                ++cpos;
            }
            return sb.toString();
        }

        int nextInt() {
            return Integer.parseInt(nextToken());
        }

        double nextDouble() {
            return Double.parseDouble(nextToken());
        }

        long nextLong() {
            return Long.parseLong(nextToken());
        }

        StrictScanner skipSpace() {
            char c = nextChar();
            assert c == ' ';
            return this;
        }
    }
}
