/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem J. John's Inversions                                 */
/*                                                              */
/* Original idea         Yury Petrov                            */
/* Problem statement     Dmitry Paraschenko                     */
/* Testset               Dmitry Paraschenko                     */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Anton Bannykh                          */
/*--------------------------------------------------------------*/
 
import java.io.*;
import java.math.*;
import java.util.*;

public class john_ab {
    public static void main(String[] arg) {
        new john_ab().run();
    }

    StrictScanner in;
    PrintWriter out;
    boolean eof;


    public void run() {
        try {
            String problemName = this.getClass().getName().split("_")[0];
            in = new StrictScanner(new FileReader(problemName + ".in"));
            out = new PrintWriter(problemName + ".out");
            solve();
        } catch (Throwable e) {
            e.printStackTrace();
            System.exit(-1);
        } finally {
            out.close();
        }
    }


    final int MAXN = 100000;
    final int MAX = 1000000000;

    void solve() throws Exception {
        int n = assertBetween(1, in.loadLine().nextInt(), MAXN, "n");
        long[] r = new long[n];
        for (int i = 0; i < n; ++i) {
            r[i] = ((long)assertBetween(1, in.loadLine().nextInt(), MAX, "r_{" + (i + 1) + "}") << 32L) | assertBetween(1, in.skipSpace().nextInt(), MAX, "b_{" + (i + 1) + "}");
        }
        Arrays.sort(r);
        for (int i = 0; i < r.length; ++i) {
            r[i] = r[i] & Integer.MAX_VALUE;
            r[i] <<= 32;
            r[i] += i;
        }
        Arrays.sort(r);
        Fenwick f = new Fenwick(n);
        long ans = 0;
        for (long v : r) {
            int i = (int)(v & Integer.MAX_VALUE);
            ans += i - f.get(i);
            f.add(i);
        }

        out.println(ans);
    }

    class Fenwick {

        int[] v;

        public Fenwick(int n) {
            v = new int[n];
        }

        void add(int i) {
            while (i < v.length) {
                ++v[i];
                i |= i + 1;
            }
        }

        int get(int i) {
            int ans = 0;
            while (i >= 0) {
                ans += v[i];
                i = (i & (i + 1)) - 1;
            }
            return ans;
        }
    }

    int assertBetween(int l, int m, int r, String name) {
        assert l <= m && m <= r : "Variable " + name + " = " + m + " not in bounds [" + l + ", " + r + "]";
        return m;
    }

    class StrictScanner extends BufferedReader {

		private String cs;
		private int cpos;

		public StrictScanner(Reader a) {
			super(a);
		}

		boolean eoln() {
			return cpos == cs.length();
		}

		StrictScanner loadLine() throws IOException {
            assert cs == null || eoln();
			cs = readLine();
			cpos = 0;
            return this;
		}

		char nextChar() {
			return cs.charAt(cpos++);
		}

		String nextToken() {
			StringBuilder sb = new StringBuilder();
			while (cpos < cs.length() && cs.charAt(cpos) != ' ') {
				sb.append(cs.charAt(cpos));
				++cpos;
			}
			return sb.toString();
		}

		int nextInt() {
			return Integer.parseInt(nextToken());
		}

		double nextDouble() {
			return Double.parseDouble(nextToken());
		}

		long nextLong() {
			return Long.parseLong(nextToken());
		}

        StrictScanner skipSpace() {
            char c = nextChar();
            assert c == ' ';
            return this;
        }
	}
}
