/*--------------------------------------------------------------*/
/* ACM ICPC 2011-2012, NEERC                                    */
/* Northern Subregional Contest                                 */
/* St Petersburg, October 29, 2011                              */
/*--------------------------------------------------------------*/
/* Problem J. John's Inversions                                 */
/*                                                              */
/* Original idea         Yury Petrov                            */
/* Problem statement     Dmitry Paraschenko                     */
/* Testset               Dmitry Paraschenko                     */
/*--------------------------------------------------------------*/
/* Solution                                                     */
/*                                                              */
/* Author                Dmitry Paraschenko                     */
/*--------------------------------------------------------------*/
 
import java.util.*;
import java.io.*;

public class john_dp {
    private static final int MAX_COUNT = 100000;
    private static final int MAX_VALUE = 1000000000;

    private BufferedReader in;
    private StringTokenizer st;
    private PrintWriter out;
    private int[] array;
    private int[] tmp;

    public void solve() throws IOException {
        int n = nextInt();
        assert 1 <= n && n <= MAX_COUNT;

        Card[] cards = new Card[n];
        for (int i = 0; i < n; i++) {
            int red = nextInt();
            int blue = nextInt();
            assert 1 <= red && red <= MAX_VALUE;
            assert 1 <= blue && blue <= MAX_VALUE;
            cards[i] = new Card(red, blue);
        }

        Arrays.sort(cards);
        array = new int[n];
        for (int i = 0; i < n; i++) {
            array[i] = cards[i].blue;
        }
        tmp = new int[n];
        long answer = solve(0, n - 1);
        out.println(answer);
    }

    private long solve(int l, int r) {
        if (l == r) {
            return 0;
        }
        int m = (l + r) / 2;
        long result = solve(l, m) + solve(m + 1, r);
        int i = l;
        int j = m + 1;
        for (int k = l; k <= r; k++) {
            if (i > m || j <= r && array[i] > array[j]) {
                result += m - i + 1;
                tmp[k] = array[j++];
            } else {
                tmp[k] = array[i++];
            }
        }
        System.arraycopy(tmp, l, array, l, r - l + 1);
        return result;
    }

    public void run() {
        try {
            solve();
        } catch (IOException e) {
            apstenu(e);
        } finally {
            out.close();
        }
    }

    private void apstenu(IOException e) {
        e.printStackTrace();
        System.exit(239);
    }

    public john_dp(String file) {
        try {
            in = new BufferedReader(new FileReader(file + ".in"));
            st = new StringTokenizer("");
            out = new PrintWriter(file + ".out");
        } catch (FileNotFoundException e) {
            apstenu(e);
        }
    }

    public String nextToken() throws IOException {
        while (!st.hasMoreTokens()) {
            String line = in.readLine();
            if (line == null) {
                return null;
            }
            st = new StringTokenizer(line);
        }
        return st.nextToken();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    public static void main(String[] arg) {
        new john_dp("john").run();
    }

    private static class Card implements Comparable<Card> {
        int red;
        int blue;

        public Card(int red, int blue) {
            this.red = red;
            this.blue = blue;
        }

        @Override
        public int compareTo(Card that) {
            if (this.red != that.red) {
                return this.red - that.red;
            }
            return this.blue - that.blue;
        }
    }
}