import java.io.*;
import java.util.*;
import java.math.*;

public class I {

	boolean test(int mask, int ind) {
		return ((mask >> ind) & 1) == 1;
	}

	final int INF = Integer.MAX_VALUE / 3;

	int n;
	int[][] dp;

	int[][] shortPath;
	int[][] prev;
	int[][] d;

	int[] best, end;

	void dijkstra(int st) {
		Arrays.fill(shortPath[st], INF);

		shortPath[st][st] = 0;
		prev[st][st] = -1;

		boolean[] used = new boolean[n];

		while (true) {
			int v = -1;
			int bestShortPath = INF;
			for (int i = 0; i < n; i++)
				if (!used[i] && shortPath[st][i] < bestShortPath) {
					bestShortPath = shortPath[st][i];
					v = i;
				}

			if (v == -1)
				break;

			used[v] = true;
			for (int to = 0; to < n; to++)
				if (d[v][to] != INF && !used[to]
						&& shortPath[st][v] + d[v][to] < shortPath[st][to]) {
					shortPath[st][to] = shortPath[st][v] + d[v][to];
					prev[st][to] = v;
				}
		}
	}
	
	void modifyPath(ArrayList<Integer> path, int en, int st) {
		while (en != st) {
			path.add(en);
			en = prev[st][en];
		}
	}

	void printPath(int mask) {
		
		if (mask == 0) {
			out.println("0 1");
			return;
		}
		
		int curCity = end[mask];
		int curDist = best[mask];

		ArrayList<Integer> path = new ArrayList<Integer>();

		while (Integer.bitCount(mask) != 1) {
			int prevMask = mask ^ (1 << curCity);
			for (int j = 0; j < n - 1; j++)
				if (test(prevMask, j))
					if (dp[prevMask][j] + shortPath[j + 1][curCity + 1] == curDist) {
						//path.add(curCity + 2);
						modifyPath(path, curCity + 1, j + 1);
						mask = prevMask;
						curCity = j;
						curDist = dp[prevMask][j];
					}
		}

		for (int i = 0; i < n - 1; i++)
			if (test(mask, i))
				//path.add(i + 2);
				modifyPath(path, i + 1, 0);

		path.add(0);
		Collections.reverse(path);
		out.print(path.size() - 1 + " ");
		for (int i : path)
			out.print(i + 1 + " ");
		out.println();
	}

	void solve() throws IOException {
		n = nextInt();
		
		if (n == 1) {
			out.println(0);
			out.println("0 1");
			out.println("0 1");
			return;
		}
		
		d = new int[n][n];
		shortPath = new int[n][n];
		for (int i = 0; i < n; i++) {
			Arrays.fill(d[i], INF);
			d[i][i] = 0;
		}

		int m = nextInt();
		for (int i = 0; i < m; i++) {
			int v1 = nextInt() - 1;
			int v2 = nextInt() - 1;
			int cost = nextInt();
			d[v1][v2] = d[v2][v1] = cost;
		}

		shortPath = new int[n][n];
		prev = new int[n][n];

		for (int i = 0; i < n; i++) {
			dijkstra(i);
		}

		dp = new int[1 << (n - 1)][n - 1];

		best = new int[1 << (n - 1)];
		end = new int[1 << (n - 1)];

		for (int mask = 1; mask < dp.length; mask++) {
			if (Integer.bitCount(mask) == 1) {
				for (int i = 0; i < n - 1; i++)
					if (test(mask, i)) {
						best[mask] = dp[mask][i] = shortPath[0][i + 1];
						end[mask] = i;
						break;
					}
			} else {
				best[mask] = INF;
				for (int i = 0; i < n - 1; i++)
					if (test(mask, i)) {
						dp[mask][i] = INF;
						int prevMask = mask ^ (1 << i);
						for (int j = 0; j < n - 1; j++)
							if (test(prevMask, j)) {
								dp[mask][i] = Math.min(dp[mask][i],
										dp[prevMask][j]
												+ shortPath[i + 1][j + 1]);

							}
						if (best[mask] > dp[mask][i]) {
							best[mask] = dp[mask][i];
							end[mask] = i;
						}
					}
			}

		}

		int maskAll = (1 << (n - 1)) - 1;

		int ans = INF;
		int bestSplit = -1;

		for (int split = 0; split < 1 << (n - 2); split++) {
			if (ans > Math.max(best[split], best[maskAll ^ split])) {
				bestSplit = split;
				ans = Math.max(best[split], best[maskAll ^ split]);
			}
		}

		out.println(ans);
		printPath(bestSplit);
		printPath(maskAll ^ bestSplit);
	}

	static final String FILENAME = "immediate";

	BufferedReader br;
	StringTokenizer st;
	PrintWriter out;

	void run() throws IOException {
		br = new BufferedReader(new FileReader(FILENAME + ".in"));
		out = new PrintWriter(FILENAME + ".out");
		solve();
		out.close();
	}

	String next() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			String s = br.readLine();
			if (s == null) {
				return null;
			}
			st = new StringTokenizer(s);
		}
		return st.nextToken();
	}

	int nextInt() throws IOException {
		return Integer.parseInt(next());
	}

	long nextLong() throws IOException {
		return Long.parseLong(next());
	}

	double parseDouble() throws IOException {
		return Double.parseDouble(next());
	}

	public static void main(String[] args) throws IOException {
		Locale.setDefault(Locale.US);
		new I().run();
	}
}
