import static java.util.Arrays.fill;

import java.io.*;
import java.util.*;

public class G {

	static List<Integer>[] edges;
	static final int INF = Integer.MAX_VALUE / 2;

	static int state(int mask, int man, int n) {
		return mask | (man << n);
	}

	static List<Integer> getRoute(int[][] p, int endState) {
		final int n = p[0].length;
		final int ALL = (1 << n) - 1;
		List<Integer> ans = new ArrayList<Integer>();
		for (int state = endState; state > 0;) {
			int mask = state & ALL;
			int man = state >>> n;
			ans.add(man);
			state = p[mask][man];
		}
		Collections.reverse(ans);
		return ans;
	}

	static int[] getCycle(int[][] g) {
		int n = g.length;
		int[][] dp = new int[1 << n][n];
		int[][] p = new int[1 << n][n];
		for (int[] dd : dp) {
			fill(dd, INF);
		}

		dp[1][0] = 0;
		for (int mask = 1; mask < 1 << n; mask++) {
			for (int man = 0; man < n; man++) {
				if ((mask & (1 << man)) == 0) {
					continue;
				}
				int cost = dp[mask][man];
				if (cost == INF) {
					continue;
				}
				int state = state(mask, man, n);
				for (int add = 0; add < n; add++) {
					if ((mask & (1 << add)) != 0) {
						continue;
					}
					if (g[man][add] == 0) {
						continue;
					}
					int newcost = cost + g[man][add];
					int mask1 = mask | (1 << add);
					if (dp[mask1][add] > newcost) {
						dp[mask1][add] = newcost;
						p[mask1][add] = state;
					}
				}
			}
		}
		int all = (1 << n) - 1;
		for (int i = 0; i < n; i++) {
			if (g[0][i] == 0) {
				continue;
			}
			if (dp[all][i] == INF) {
				continue;
			}
			List<Integer> cycle = getRoute(p, state(all, i, n));
			int[] ret = new int[n];
			for (int j = 0; j < n; j++) {
				ret[j] = cycle.get(j);
			}
			return ret;
		}
		throw new AssertionError();
	}

	static void solve() throws Exception {
		int n = nextInt();
		int k = nextInt();
		int m = nextInt();
		edges = new List[n];
		for (int i = 0; i < n; i++) {
			edges[i] = new ArrayList<Integer>();
		}
		int[][] g = new int[k][k];
		for (int i = 0; i < m; i++) {
			int from = nextInt() - 1;
			int to = nextInt() - 1;
			if (from < k && to < k) {
				g[from][to] = g[to][from] = 1;
			}
			edges[from].add(to);
			edges[to].add(from);
		}		
		int[] color = new int[n];
		fill(color, -1);
		int[] cycle = getCycle(g);
		for (int i = 0; i < k; i++) {
			color[cycle[i]] = i;
		}
		Queue<Integer> q = new ArrayDeque<Integer>();
		boolean[] was = new boolean[n];
		for (int i = 0; i < k; i++) {
			was[i] = true;
			q.add(i);
		}
		boolean[] hasIt = new boolean[k];
		while (!q.isEmpty()) {
			int v = q.poll();
			for (int i : edges[v]) {
				if (was[i]) {
					continue;
				}
				was[i] = true;
				q.add(i);
			}
			if (v < k) {
				continue;
			}
			fill(hasIt, false);
			for (int i : edges[v]) {
				if (color[i] >= 0) {
					hasIt[color[i]] = true;
				}
			}
			for (int i = 0; i < k; i++) {
				int j = i + 1;
				if (j == k) {
					j = 0;
				}
				if (!hasIt[i] && hasIt[j]) {
					color[v] = i;
				}
			}
			if (color[v] < 0) {
				throw new AssertionError();
			}
		}
		for (int i : color) {
			out.print(1 + i + " ");
		}
	}

	static int nextInt() throws IOException {
		return Integer.parseInt(next());
	}

	static String next() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			String line = br.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}

	static BufferedReader br;
	static PrintWriter out;
	static StringTokenizer st;

	public static void main(String[] args) throws Exception {
		br = new BufferedReader(new FileReader("galaxy.in"));
		out = new PrintWriter("galaxy.out");
		solve();
		out.close();
	}
}
