import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Locale;
import java.util.StringTokenizer;

public class Main {
	private static final String TASKNAME = "galaxy";

	private void solve() throws Exception {
		int n = nextInt();
		int k = nextInt();
		int m = nextInt();
		ArrayList<Integer>[] g = new ArrayList[n];
		for (int i = 0; i < n; ++i) {
			g[i] = new ArrayList<Integer>();
		}

		for (int i = 0; i < m; ++i) {
			int u = nextInt() - 1;
			int v = nextInt() - 1;
			g[u].add(v);
			g[v].add(u);
		}

		int[] colors = new int[n];
		Arrays.fill(colors, -1);
		int[][] nc = new int[k][n];
		for (int i = 0; i < k; ++i) {
			colors[i] = i;
			for (int j = 0; j < k; ++j) {
				nc[j][i] = (i + j) % k;
			}
		}

		int[] queue = new int[n];
		int ql = 0;
		int qr = 0;
		boolean[] vis = new boolean[n];
		for (int i = 0; i < k; ++i) {
			queue[qr++] = i;
			vis[i] = true;
		}

		int[] nextVer = new int[k];
		while (ql != qr) {
			int v = queue[ql++];
			if (colors[v] >= 0) {
				for (int u : g[v]) {
					if (!vis[u]) {
						vis[u] = true;
						queue[qr++] = u;
					}
				}
				continue;
			}

			int nei = 0;
			for (int u : g[v]) {
				int c = colors[u];
				if (c >= 0) {
					nei |= 1 << c;
				}
			}
//			System.err.println(v + " " + colors[v]);

			int set = 0;
			for (int u : g[v]) {
				int c = colors[u];
				if (c < 0) {
					continue;
				}
				set |= 1 << nc[k - 1][u];
				nextVer[nc[k - 1][u]] = u;
			}

			for (int i = 0; i < k; ++i) {
				if ((nei & (1 << i)) == 0 && (set & (1 << i)) != 0) {
					colors[v] = i;
					int u = nextVer[i];
					for (int j = 0; j < k - 1; ++j) {
						nc[j + 1][v] = nc[j][u];
					}
					nc[0][v] = colors[v];
					break;
				}
			}
			if (colors[v] < 0) {
				throw new AssertionError();
			}
			for (int u : g[v]) {
				if (!vis[u]) {
					vis[u] = true;
					queue[qr++] = u;
				}
			}
		}
		
		for (int i = 0 ; i < n; ++i) {
			print((colors[i] + 1) +  " ");
		}
		println("");
	}

	public static void main(String[] args) throws FileNotFoundException {
		long time = System.currentTimeMillis();
		Locale.setDefault(Locale.US);
		new Main().run();
		System.err.printf("%.3f\n", 1e-3 * (System.currentTimeMillis() - time));
	}

	BufferedReader reader;
	PrintWriter writer;
	StringTokenizer tokenizer;

	String nextToken() throws IOException {
		while (tokenizer == null || !tokenizer.hasMoreTokens()) {
			tokenizer = new StringTokenizer(reader.readLine());
		}
		return tokenizer.nextToken();
	}

	int nextInt() throws NumberFormatException, IOException {
		return Integer.parseInt(nextToken());
	}

	long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}

	void print(Object o) {
		writer.print(o);
	}

	void println(Object o) {
		writer.println(o);
	}

	void printf(String format, Object... o) {
		writer.printf(format, o);
	}

	private void run() {
		try {
			reader = new BufferedReader(new FileReader(TASKNAME + ".in"));
			writer = new PrintWriter(TASKNAME + ".out");

			solve();

			reader.close();
			writer.close();
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

}
