import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Locale;
import java.util.StringTokenizer;

public class Main {
	private static final String TASKNAME = "immediate";

	private void solve() throws Exception {
		int n = nextInt();
		int m = nextInt();
		int[][] g = new int[n][n];
		int inf = Integer.MAX_VALUE / 2;

		for (int[] a : g) {
			Arrays.fill(a, inf);
		}
		for (int i = 0; i < m; ++i) {
			int u = nextInt() - 1;
			int v = nextInt() - 1;
			int t = nextInt();
			g[u][v] = g[v][u] = t;
		}

		int[][] dp = new int[n][1 << n];
		for (int[] a : dp) {
			Arrays.fill(a, inf);
		}
		int[][] from = new int[n][1 << n];

		dp[0][1] = 0;
		for (int mask = 0; mask < (1 << n); ++mask) {
			for (int time = 0; time < n; ++time) {
				for (int v = 0; v < n; ++v) {
					int d = dp[v][mask];
					if (d == inf) {
						continue;
					}
					for (int u = 0; u < n; ++u) {
						if (g[v][u] == inf) {
							continue;
						}
						int nd = d + g[v][u];
						int nmask = mask | (1 << u);
						if (dp[u][nmask] > nd) {
							dp[u][nmask] = nd;
							from[u][nmask] = mask * 20 + v;
						}
					}
				}
			}
		}

		int[] min = new int[1 << n];
		int[] minV = new int[1 << n];
		for (int mask = 0; mask < (1 << n); ++mask) {
			int cur = inf;
			int u = -1;
			for (int v = 0; v < n; ++v) {
				if (dp[v][mask] < cur) {
					cur = dp[v][mask];
					u = v;
				}
			}
			min[mask] = cur;
			minV[mask] = u;
		}
//		System.err.println(min[(1 << 4) | (1 << 5)]);

		int best = inf;
		int b1 = -1;
		int b2 = -1;

		int all = (1 << n) - 1;
		for (int mask1 = 1; mask1 < (1 << n); ++mask1) {
			int need = all ^ mask1;
			for (int subMask = mask1;; subMask = (subMask - 1) & mask1) {
				int mask2 = need | subMask;
				int score = Math.max(min[mask1], min[mask2]);
				if (score < best) {
					best = score;
					b1 = mask1;
					b2 = mask2;
				}
				if (subMask == 0) {
					break;
				}
			}
		}

//		System.err.println(min[1 | (2) | 8 | 16]);
//		System.err.println(min[(1 << 4) - 1]);
		println(best);
		printAns1(b1, minV[b1], from);
		printAns1(b2, minV[b2], from);
	}

	private void printAns1(int mask, int v, int[][] from) {
		ArrayList<Integer> path;
		path = new ArrayList<Integer>();
		while (mask > 0) {
			int f = from[v][mask];
			int nv = f % 20;
			int nmask = f / 20;
			path.add(v);
			v = nv;
			mask = nmask;
		}
		Collections.reverse(path);
		print(path.size() - 1);
		for (int i : path) {
			print(" " + (i + 1));
		}
		println("");
	}

	public static void main(String[] args) throws FileNotFoundException {
		long time = System.currentTimeMillis();
		Locale.setDefault(Locale.US);
		new Main().run();
		System.err.printf("%.3f\n", 1e-3 * (System.currentTimeMillis() - time));
	}

	BufferedReader reader;
	PrintWriter writer;
	StringTokenizer tokenizer;

	String nextToken() throws IOException {
		while (tokenizer == null || !tokenizer.hasMoreTokens()) {
			tokenizer = new StringTokenizer(reader.readLine());
		}
		return tokenizer.nextToken();
	}

	int nextInt() throws NumberFormatException, IOException {
		return Integer.parseInt(nextToken());
	}

	long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}

	void print(Object o) {
		writer.print(o);
	}

	void println(Object o) {
		writer.println(o);
	}

	void printf(String format, Object... o) {
		writer.printf(format, o);
	}

	private void run() {
		try {
			reader = new BufferedReader(new FileReader(TASKNAME + ".in"));
			writer = new PrintWriter(TASKNAME + ".out");

			solve();

			reader.close();
			writer.close();
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

}
