import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Locale;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.TreeMap;

public class Main {
	private static final String TASKNAME = "john";
	
	class Fenwick {
		long[] vals;
		public Fenwick(int n) {
			vals = new long[n + 1];
		}
		
		int next(int x) {
			return (x << 1) - (x & (x - 1));
		}
		int prev(int x) {
			return (x & (x - 1));
		}
		
		void modify(int pos, int x) {
			++pos;
			while (pos < vals.length) {
				vals[pos] += x;
				pos = next(pos);
			}
		}
		
		long get(int l, int r) {
			return get(r) - get(l - 1); 
		}

		private long get(int pos) {
			++pos;
			long ans = 0;
			while (pos > 0) {
				ans += vals[pos];
				pos = prev(pos);
			}
			return ans;
		}
	}

	private void solve() throws Exception {
		int n = nextInt();
		final int[] a = new int[n];
		final int[] b = new int[n];
		Integer[] indices = new Integer[n];
		
		TreeMap<Integer, Integer> id = new TreeMap<Integer, Integer>();
		for (int i = 0; i < n; ++i) {
			a[i] = nextInt();
			id.put(a[i], 0);
			b[i] = nextInt();
			id.put(b[i], 0);
			indices[i] = i;
		}
		
		int count = 0;
		for (Map.Entry<Integer, Integer> entry : id.entrySet()) {
			id.put(entry.getKey(), count++);
		}
		
		for (int i = 0; i < n; ++i) {
			a[i] = id.get(a[i]);
			b[i] = id.get(b[i]);
		}

		println(Math.min(invers(a, b, indices), invers(b, a, indices)));
	}
	
	long invers(final int[] a, final int[] b, Integer[] indices) {
		Arrays.sort(indices, new Comparator<Integer>() {
			@Override
			public int compare(Integer o1, Integer o2) {
				int d = a[o1] - a[o2];
				if (d == 0) {
					return b[o1] - b[o2];
				}
				return d;
			}
		});
		
		Fenwick fenwick = new Fenwick(a.length + b.length + 5);
		long ans = 0;
		int n = a.length;
		for (int i = 0; i < n; ++i) {
			int ind = indices[i];
			ans += fenwick.get(b[ind] + 1, a.length * 2);
			fenwick.modify(b[ind], 1);
		}
		return ans;
	}

	public static void main(String[] args) throws FileNotFoundException {
		long time = System.currentTimeMillis();
		Locale.setDefault(Locale.US);
		new Main().run();
		System.err.printf("%.3f\n", 1e-3 * (System.currentTimeMillis() - time));
	}

	BufferedReader reader;
	PrintWriter writer;
	StringTokenizer tokenizer;

	String nextToken() throws IOException {
		while (tokenizer == null || !tokenizer.hasMoreTokens()) {
			tokenizer = new StringTokenizer(reader.readLine());
		}
		return tokenizer.nextToken();
	}

	int nextInt() throws NumberFormatException, IOException {
		return Integer.parseInt(nextToken());
	}

	long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}

	void print(Object o) {
		writer.print(o);
	}

	void println(Object o) {
		writer.println(o);
	}

	void printf(String format, Object... o) {
		writer.printf(format, o);
	}

	private void run() {
		try {
			reader = new BufferedReader(new FileReader(TASKNAME + ".in"));
			writer = new PrintWriter(TASKNAME + ".out");

			solve();

			reader.close();
			writer.close();
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

}
