#include <stdio.h>
#include <string.h>
#include <algorithm>
#include <vector>

using namespace std;

#define NMAX 50
#define QMOD 511
#define INF 1000000000

char A[NMAX][NMAX];
int T, te, M, N, i, j, minm, numm;

int cost[2 * NMAX][2 * NMAX];
int smin[2 * NMAX];
int q[QMOD + 1], p[2 * NMAX];
int flow[2 * NMAX][2 * NMAX], cap[2 * NMAX][2 * NMAX], t[2 * NMAX], inq[2 * NMAX];

int MinCostMaxFlow(int x, int y) {
	int i, j, li, ls, min_cost = 0, max_flow = 0, best_possible_cost;

	//fprintf(stderr, "testing x=%d y=%d\n", x, y);
	
	memset(flow, 0, sizeof(flow));
	memset(cap, 0, sizeof(cap));
	memset(cost, 0, sizeof(cost));
	memset(p, 0, sizeof(p));

	for (i = 1; i <= M; i++) {
		cap[0][i] = x;
		cost[0][i] = 0;
	}

	for (i = M + 1; i <= M + N; i++) {
		cap[i][M + N + 1] = y;
		cost[i][M + N + 1] = 0;
	}
	
	for (i = 1; i <= M; i++)
		for (j = M + 1; j <= M + N; j++) {
			cap[i][j] = 1;
			if (A[i][j - M] == '1') {
				min_cost++;
				cost[i][j] = -1;
			} else {
				cost[i][j] = 1;
			}
		}

	// Do the flow.
	while (1) {
		//fprintf(stderr, "max_flow=%d/%d\n", max_flow, x * M);
		if (max_flow == x * M)
			break;

		li = 0;
		ls = 0;
	
		for (i = 1; i <= M; i++) {
			if (flow[0][i] == cap[0][i]) {
				smin[i] = INF;
				inq[i] = 0;
			} else {
				smin[i] = 0;
				inq[i] = 1;
				q[ls] = i;
				ls = (ls + 1) & QMOD;
				t[i] = 1;
			}
			p[i] = 0;
		}

		for (i = M + 1; i <= M + N; i++) {
			smin[i] = INF;
			inq[i] = 0;
			p[i] = 0;			
			//if (flow[i][M + N + 1] < cap[i][M + N + 1])
			//	fprintf(stderr, "good candidate: %d\n", i);
		}

		while (li != ls) {
			i = q[li];
			inq[i] = 0;
			li = (li + 1) & QMOD;

			if (p[i] > 0 && inq[p[i]])
				continue;
			if (p[p[i]] > 0 && inq[p[p[i]]])
				continue;
			if (p[p[p[i]]] > 0 && inq[p[p[p[i]]]])
				continue;
			if (p[p[p[p[i]]]] > 0 && inq[p[p[p[p[i]]]]])
				continue;
				
			if (i <= M) {
				for (j = M + 1; j <= M + N; j++) {
					if (flow[i][j] < cap[i][j]) {
						if (smin[i] + cost[i][j] < smin[j]) {
							smin[j] = smin[i] + cost[i][j];
							p[j] = i;
							t[j] = 1;
							if (!inq[j]) {
								inq[j] = 1;
								q[ls] = j;
								ls = (ls + 1) & QMOD;
							}
						}
					}
				}
			} else {
				for (j = 1; j <= M; j++) 
					if (flow[j][i] > 0) {
						if (smin[i] - cost[j][i] < smin[j]) {
							smin[j] = smin[i] - cost[j][i];
							p[j] = i;
							t[j] = 2;
							if (!inq[j]) {
								inq[j] = 1;
								q[ls] = j;
								ls = (ls + 1) & QMOD;
							}
						}
					}
			}	
		}

		vector<pair<int, int> > dest;
		best_possible_cost = min_cost;
		for (j = M + 1; j <= M + N; j++)
			if (smin[j] < INF && flow[j][M + N + 1] < cap[j][M + N + 1]) {
				dest.push_back(make_pair(smin[j], j));
				best_possible_cost += smin[j] * (cap[j][M + N + 1] - flow[j][M + N + 1]);
			}

		if (best_possible_cost >= minm)
			return INF;

		//fprintf(stderr, "dest.size()=%d ls=%d\n", dest.size(), ls);
			
		sort(dest.begin(), dest.end());

		memset(inq, 0, sizeof(inq));
		for (int did = dest.size() - 1; did >= 0; did--) {
			int node = dest[did].second;

			// Retrace the path back from node to 0.
			while (node > 0) {
				if (inq[node])
					break;
				inq[node] = 1;
				node = p[node];
			}

			if (node == 0) {
				node = dest[did].second;			

				max_flow++;
				min_cost += smin[node];
				flow[node][M + N + 1]++;

				while (node > 0) {
					if (t[node] == 1) {
						flow[p[node]][node]++;
						//fprintf(stderr, "inc flow %d->%d\n", p[node], node);
					} else {
						flow[node][p[node]]--;
						//fprintf(stderr, "dec flow %d->%d\n", node, p[node]);
					}
					node = p[node];
				}
			
				//break;
			}
		}
	}

	//fprintf(stderr, "x=%d y=%d min_cost=%d\n", x, y, min_cost);
	return min_cost;
}

int main() {
	//freopen("x.txt", "r", stdin);
	scanf("%d", &T);
	te = 0;
	while (T--) {
		scanf("%d %d", &M, &N);
		for (i = 1; i <= M; i++)
			scanf("%s", &A[i][1]);

		minm = M * N;
		for (int x = 0; x <= N; x++)
			for (int y = 0; y <= M; y++)
				if (x * M == y * N) {
					numm = MinCostMaxFlow(x, y);
					if (numm < minm)
						minm = numm;
				}
		
		te++;
		printf("Case %d: %d\n", te, minm);
	}
	
	return 0;
}
